@@ -14,7 +14,7 @@ Readonly::Array our @EXPORT_OK => qw(err);
 Readonly::Scalar my $EVAL => 'eval {...}';
 
 # Version.
-our $VERSION = 0.15;
+our $VERSION = 0.16;
 
 # Ignore die signal.
 $SIG{__DIE__} = 'IGNORE';
@@ -63,6 +63,7 @@ Error::Pure::HTTP::Error - Error::Pure module with error on one line over HTTP.
 =head1 SYNOPSIS
 
  use Error::Pure::HTTP::Error qw(err);
+
  err 'This is a fatal error', 'name', 'value';
 
 =head1 SUBROUTINES
@@ -77,6 +78,8 @@ Error::Pure::HTTP::Error - Error::Pure module with error on one line over HTTP.
 
 =head1 EXAMPLE1
 
+=for comment filename=error.pl
+
  use strict;
  use warnings;
 
@@ -92,6 +95,8 @@ Error::Pure::HTTP::Error - Error::Pure module with error on one line over HTTP.
 
 =head1 EXAMPLE2
 
+=for comment filename=error_with_arguments.pl
+
  use strict;
  use warnings;
 
@@ -125,7 +130,7 @@ Install the Error::Pure modules.
 
 =head1 REPOSITORY
 
-L<https://github.com/tupinek/Error-Pure-HTTP>
+L<https://github.com/michal-josef-spacek/Error-Pure-HTTP>
 
 =head1 AUTHOR
 
@@ -135,11 +140,12 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
- © 2012-2018 Michal Josef Špaček
- BSD 2-Clause License
+© 2012-2023 Michal Josef Špaček
+
+BSD 2-Clause License
 
 =head1 VERSION
 
-0.15
+0.16
 
 =cut
