@@ -14,7 +14,7 @@ Readonly::Scalar my $EMPTY_STR => q{};
 Readonly::Scalar my $EVAL => 'eval {...}';
 
 # Version.
-our $VERSION = 0.15;
+our $VERSION = 0.16;
 
 # Ignore die signal.
 $SIG{__DIE__} = 'IGNORE';
@@ -74,6 +74,7 @@ Error::Pure::HTTP::Print - Error::Pure module for simple error print over HTTP.
 =head1 SYNOPSIS
 
  use Error::Pure::HTTP::Print qw(err);
+
  err 'This is a fatal error', 'name', 'value';
 
 =head1 SUBROUTINES
@@ -88,6 +89,8 @@ Error::Pure::HTTP::Print - Error::Pure module for simple error print over HTTP.
 
 =head1 EXAMPLE1
 
+=for comment filename=print.pl
+
  use strict;
  use warnings;
 
@@ -103,6 +106,8 @@ Error::Pure::HTTP::Print - Error::Pure module for simple error print over HTTP.
 
 =head1 EXAMPLE2
 
+=for comment filename=print_with_arguments.pl
+
  use strict;
  use warnings;
 
@@ -135,7 +140,7 @@ Install the Error::Pure modules.
 
 =head1 REPOSITORY
 
-L<https://github.com/tupinek/Error-Pure-HTTP>
+L<https://github.com/michal-josef-spacek/Error-Pure-HTTP>
 
 =head1 AUTHOR
 
@@ -145,11 +150,12 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
- © 2012-2018 Michal Josef Špaček
- BSD 2-Clause License
+© 2012-2023 Michal Josef Špaček
+
+BSD 2-Clause License
 
 =head1 VERSION
 
-0.15
+0.16
 
 =cut
